import type { ServiceId, UCDataFromLocalStorage } from './types.js';
/**
 * A method to check if user has interacted with the consent prompt and given consent information.
 *
 * @example
 * const userInteracted = hasUserInteracted()
 * if (userInteracted) {
 *  actionRequiredConsentInfoGiven()
 * }
 *
 * @see `setUserHasInteracted`
 */
export declare const hasUserInteracted: () => boolean;
/**
 * A method to set that user has interacted with the consent prompt and given consent information.
 *
 * @example setUserHasInteracted()
 *
 * @see `hasUserInteracted`
 */
export declare const setUserHasInteracted: () => void;
/**
 * Programmatic way to show First Layer.
 * @see https://usercentrics.com/docs/web/features/api/control-ui/#showfirstlayer
 *
 * @example showFirstLayer()
 */
export declare const showFirstLayer: () => Promise<void>;
/**
 * Programmatic way to show Second Layer.
 * @see https://usercentrics.com/docs/web/features/api/control-ui/#showsecondlayer
 *
 * @example showSecondLayer()
 */
export declare const showSecondLayer: () => Promise<void>;
/**
 * Programmatic way to show the details of a service
 * @see https://usercentrics.com/docs/web/features/api/control-ui/#showservicedetails
 *
 * @example showServiceDetails('my-service-id')
 */
export declare const showServiceDetails: (serviceId: ServiceId) => Promise<void>;
/**
 * A method to get consent status saved to localStorage
 *
 * @example
 * const consents = getConsentsFromLocalStorage()
 * const hasConsent = consents['my-service-id']?.consent === true
 */
export declare const getConsentsFromLocalStorage: () => UCDataFromLocalStorage["consent"]["services"];
/**
 * Updates consents for individual or multiple services.
 * @see https://usercentrics.com/docs/web/features/api/control-functionality/#updateservicesconsents
 *
 * @example updateServicesConsents([{ id: 'my-service-id', consent: true }])
 */
export declare const updateServicesConsents: (servicesConsents: {
    id: ServiceId;
    consent: boolean;
}[]) => Promise<void>;
/**
 * Programmatic way to set language for the CMP.
 * @param countryCode Two character country code, e.g. "en" = set language to English
 * @see https://usercentrics.com/docs/web/features/api/control-functionality/#changelanguage
 *
 * @example changeLanguage("fi")
 */
export declare const changeLanguage: (countryCode: string) => Promise<void>;
/** @returns `true` if the Usercentrics dialog is currently open. */
export declare const isOpen: () => boolean;
